@@ -19,15 +19,14 @@ $suite->parameters(
         {
             'ping_count' => 5
         });
-#my $formatter = Test::System::Output::Factory->new('console');
-
-use TAP::Formatter::ConsoleTable;
-my $formatter = TAP::Formatter::ConsoleTable->new({
-        color => 1});
-#$formatter->output_file('output.html');
-$suite->runtests('example/execute_these_tests.yaml', {
-        formatter => $formatter,
-        verbosity => 1,
+my $formatter = Test::System::Output::Factory->new('console',
+        {
+        verbosity => -3
+        });
+$suite->runtests(['ping', 'cpu'], {
+        verbosity => -2,
+        lib => ['foo']
+#formatter => $formatter,
         });
 
 
